pub fn assert_has_data_attr(output: &RenderOutput, name: &str) -> boolExpand description
Assert that a RenderOutput has a data attribute with the given name.
Returns true if a data-{name} attribute is present.
pub fn assert_has_data_attr(output: &RenderOutput, name: &str) -> boolAssert that a RenderOutput has a data attribute with the given name.
Returns true if a data-{name} attribute is present.